# __init__.py


from pyperclip import copy
from hashwd import pass_defaults
from hashwd.pass_defaults import MIN_WORDS, MAX_WORDS, MIN_NUMBERS, MAX_NUMBERS, MIN_SYMBOLS, MAX_SYMBOLS, SYMBOLS, DICTIONARY_FILE, WORDS_DEFAULT, NUMBERS_DEFAULT, SYMBOLS_DEFAULT
from hashwd import hashwd
from hashwd.hashwd import generate_password, clear_clipboard